#!/usr/bin/env python3
# -*- coding: utf-8 -*-

# This module is used to read information about hanja from a textfile.

import os


def read_hanja_txt():
    """ Returns dictionary that maps hanja characters to their information.

    :return: dictionary containing information about Hanja characters
    :rtype: dict
    """
    hanja_dict = dict()
    for line in _read_file(_get_hanja_txt_filepath()).splitlines():
        if line == "" or line.startswith("#"):
            continue
        _extract_information_from_line(hanja_dict, line)
    return hanja_dict


def _read_file(filepath):
    """ Returns all content of a textfile as a single string.

    :param str filepath: filepath of file to read contents from

    :return: contents of file with given filepath
    :rtype: str
    """
    with open(filepath, "r") as f:
        s = f.read()
    return s


def _get_hanja_txt_filepath():
    """ Returns filepath of location where hanja.txt is expected to be found.

    :return: filepath of hanja.txt file
    :rtype: str
    """
    this_dir = os.path.dirname(os.path.realpath(__file__))
    return os.path.join(this_dir, "hanja.txt")


def _extract_information_from_line(hanja_dict, line):
    """ Extracts information about Hanja character from line, and stores
        information about Hanja character in a dictionary.

    :param dict hanja_dict: used to store information about Hanja
    :param str line: line containing information about Hanja character
    """
    (hanja_field, hangul_field, meaning_field) = line.split("\t")
    for hanja_ch in hanja_field.split("/"):
        assert len(hanja_ch) == 1
        assert hanja_ch not in hanja_dict.keys()
        hanja_dict[hanja_ch] = (hangul_field, meaning_field)
